const storage = require("uxp").storage;
const lfs = storage.localFileSystem;


const PANEL_HTML = `
<p><form id="formGetImage"><button id="buttonGetImage" type="submit">Upload SVG</button></form></p>
<div class="container" id="div_images"/>
`;


var _mainPanel;


function getMainPanel() {
    _mainPanel = document.createElement("div");
    _mainPanel.innerHTML = PANEL_HTML;
    _mainPanel.querySelector("#formGetImage").addEventListener("submit", getImage);
    return _mainPanel;
}


async function getImage() {
    let fileImage;

    try {
        fileImage = await lfs.getFileForOpening({ types: ["svg"] });
    } catch (err) {
        console.error("Error in lfs.getFileForOpening: " + err);
    }

    if (fileImage) {
        let divImages = document.getElementById("div_images");

        while (divImages.firstChild) {
            divImages.removeChild(divImages.firstChild);
        }

        console.log("Opening image " + fileImage.nativePath);

        let imageBuffer;

        try {
            imageBuffer = await fileImage.read({ format: storage.formats.utf8 });
        } catch (err) {
            console.error("Error reading SVG file: " + err);
        }

        if (imageBuffer) {
            try {
                let elemImage = document.createElement("img");
                elemImage.setAttribute("src", "data:image/svg+xml;charset=utf-8," + imageBuffer);
                divImages.appendChild(elemImage);
            } catch (err) {
                console.error("Error setting image: " + err);
            }
        }
    } else {
        console.log("User closed file picker");
    }
}


function show(event) {
    if (!_mainPanel) {
        event.node.appendChild(getMainPanel());
    }
}


module.exports = {
    panels: {
        mainPanel: {
            show
        }
    }
};
